using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MindFusion.Scheduling.WinForms;

namespace WindowsApplication187
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			calendar1.EndDate = new DateTime(2012, 1, 1);
			calendar1.SizeChanged += calendar1_SizeChanged;
		}

		private void calendar1_SizeChanged(object sender, EventArgs e)
		{
			SetScale();
		}

		private void button1_Click(object sender, EventArgs e)
		{
			SetScale();
		}

		private void SetScale()
		{
			int numberOfDaysToFit = 30;

			Rectangle bounds = calendar1.GetElementBounds(CalendarElement.ResourceViewCell, 0);
			float size = GetCellSize(calendar1);

			float visibleCells = (float)Math.Floor(bounds.Width / size);

			calendar1.ResourceViewSettings.TimelineScale = (int)Math.Floor(((bounds.Width / numberOfDaysToFit) / size) * 100);
		}

		/// <summary>
		/// Calculates the size of a single cell, based on the
		/// settings specified for the view timelines.
		/// </summary>
		public static float GetCellSize(Calendar calendar)
		{
			ResourceViewSettings settings = calendar.ResourceViewSettings;
			Graphics graphics = calendar.CreateGraphics();

			Font headerFont = settings.BottomTimelineSettings.Style.HeaderFont;
			if (headerFont == null)
				headerFont = settings.Style.HeaderFont;

			float maxSize = 0;
			foreach (DateTime date in Dates)
			{
				string sampleCellContents =
					date.ToString(settings.BottomTimelineSettings.Format, calendar.Culture).Trim();
				SizeF size = graphics.MeasureString(sampleCellContents, headerFont);

				maxSize = Math.Max(size.Width, maxSize);
			}

			// Add margins
			maxSize += 5f;

			graphics.Dispose();

			return maxSize;
		}

		/// <summary>
		/// Dates that are used to estimate the maximum required amount of space for
		/// a timeline cell text.
		/// </summary>
		private static DateTime[] Dates = new DateTime[]
		{
			new DateTime(2000,  1, 28, 23, 59, 59),
			new DateTime(2000,  2, 28, 23, 59, 59),
			new DateTime(2000,  3, 28, 23, 59, 59),
			new DateTime(2000,  4, 28, 23, 59, 59),
			new DateTime(2000,  5, 28, 23, 59, 59),
			new DateTime(2000,  6, 28, 23, 59, 59),
			new DateTime(2000,  7, 28, 23, 59, 59),
			new DateTime(2000,  8, 28, 23, 59, 59),
			new DateTime(2000,  9, 28, 23, 59, 59),
			new DateTime(2000, 10, 28, 23, 59, 59),
			new DateTime(2000, 11, 28, 23, 59, 59),
			new DateTime(2000, 12, 28, 23, 59, 59),
		};
	}
}